@@ -1,9 +1,11 @@
 import { Basis } from "./basis/basis";
+import { Cell } from "./cell/cell";
 import { ATOMIC_COORD_UNITS, coefficients, tolerance, units } from "./constants";
 import { AtomicConstraints } from "./constraints/constraints";
 import { Lattice, nonPeriodicLatticeScalingFactor } from "./lattice/lattice";
 import { DEFAULT_LATTICE_UNITS, LATTICE_TYPE_CONFIGS } from "./lattice/lattice_types";
 import { ReciprocalLattice } from "./lattice/reciprocal/lattice_reciprocal";
+import { UnitCell } from "./lattice/unit_cell";
 import { defaultMaterialConfig, Material } from "./material";
 import MadeMath from "./math";
 import parsers from "./parsers/parsers";
@@ -19,6 +21,8 @@ export const Made = {
     Material,
     defaultMaterialConfig,
     Lattice,
+    Cell,
+    UnitCell,
     nonPeriodicLatticeScalingFactor,
     ReciprocalLattice,
     Basis,
@@ -29,3 +33,25 @@ export const Made = {
     LATTICE_TYPE_CONFIGS,
     DEFAULT_LATTICE_UNITS,
 };
+
+export {
+    coefficients,
+    tolerance,
+    units,
+    ATOMIC_COORD_UNITS,
+    Material,
+    defaultMaterialConfig,
+    Lattice,
+    Cell,
+    UnitCell,
+    nonPeriodicLatticeScalingFactor,
+    ReciprocalLattice,
+    Basis,
+    AtomicConstraints,
+    parsers,
+    tools,
+    LATTICE_TYPE_CONFIGS,
+    DEFAULT_LATTICE_UNITS,
+};
+
+export type { MaterialInMemoryEntity } from "./materialMixin";
