@@ -1,5 +1,5 @@
 import { HasConsistencyChecksHasMetadataNamedDefaultableInMemoryEntity } from "@mat3ra/code/dist/js/entity";
-import type { MaterialSchema } from "@mat3ra/esse/dist/js/types";
+import type { ConsistencyCheck, MaterialSchema } from "@mat3ra/esse/dist/js/types";
 
 import {
     type MaterialMixinConstructor,
@@ -11,9 +11,18 @@ import {
 export { defaultMaterialConfig };
 
 const BaseInMemoryEntity = HasConsistencyChecksHasMetadataNamedDefaultableInMemoryEntity;
+
 type BaseMaterial = MaterialMixinConstructor & typeof BaseInMemoryEntity;
 
-export class Material extends (BaseInMemoryEntity as BaseMaterial) {
+// TODO: remove in-line type creation
+type MaterialSchemaWithConsistencyChecksAsString = Omit<MaterialSchema, "consistencyChecks"> & {
+    consistencyChecks?: ConsistencyCheck[];
+};
+
+export class Material
+    extends (BaseInMemoryEntity as BaseMaterial)
+    implements MaterialSchemaWithConsistencyChecksAsString
+{
     constructor(config: MaterialSchema) {
         super(config);
         materialMixin(this);
