@@ -1,4 +1,9 @@
-import { BasisSchema, Coordinate3DSchema, Vector3DSchema } from "@mat3ra/esse/dist/js/types";
+import {
+    BasisSchema,
+    Coordinate3DSchema,
+    MaterialSchema,
+    Vector3DSchema,
+} from "@mat3ra/esse/dist/js/types";
 import s from "underscore.string";
 
 import { ConstrainedBasis } from "../basis/constrained_basis";
@@ -9,7 +14,6 @@ import { ATOMIC_COORD_UNITS } from "../constants";
 import { AtomicConstraintValue } from "../constraints/constraints";
 import { Lattice } from "../lattice/lattice";
 import math from "../math";
-import { MaterialJSON } from "../types";
 
 const _print = (x: number, printFormat = "%14.9f") => s.sprintf(printFormat, math.precise(x));
 const _latticeVectorsToString = (vectors: Vector3DSchema[]) =>
@@ -21,7 +25,7 @@ const atomicConstraintsCharFromBool = (bool: boolean): string => (bool ? "T" : "
  * @param materialOrConfig - material class instance or config object.
  * @param omitConstraints - whether to discard constraints passed with material.
  */
-function toPoscar(materialOrConfig: MaterialJSON, omitConstraints = false): string {
+function toPoscar(materialOrConfig: MaterialSchema, omitConstraints = false): string {
     const lattice = new Lattice(materialOrConfig.lattice);
     const vectorsAsString = _latticeVectorsToString(lattice.vectorArrays);
     // @ts-ignore
@@ -96,9 +100,9 @@ function fromPoscar(fileContent: string): object {
         startLine = 8;
     }
 
-    const elements: AtomicElementValue[] = atomSymbols
+    const elements = atomSymbols
         .map((symbol: string, i: number): string[] => Array(atomCounts[i]).fill(symbol))
-        .reduce((a, b) => a.concat(b), []);
+        .reduce((a, b) => a.concat(b), []) as AtomicElementValue[];
 
     // Atom coordinates and constraints
     const coordinates: AtomicCoordinateValue[] = [];
